CURVES = {
    "month": {
        "modern_brand": [
            {
                "anchor_type": "month_of_year",
                "anchor_point": 1.0,
                "anchor_value": 0.08279169558999999
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 2.0,
                "anchor_value": 0.15208786289999998
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 3.0,
                "anchor_value": 0.22606802550000002
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 4.0,
                "anchor_value": 0.30519685399999996
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 5.0,
                "anchor_value": 0.3898501007
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 6.0,
                "anchor_value": 0.46571476100000003
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 7.0,
                "anchor_value": 0.5437966463
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 8.0,
                "anchor_value": 0.6254869003
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 9.0,
                "anchor_value": 0.7070824991
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 10.0,
                "anchor_value": 0.7952064343
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 11.0,
                "anchor_value": 0.8861585502
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 12.0,
                "anchor_value": 1.0
            }
        ],
        "modern_distributor": [
            {
                "anchor_type": "month_of_year",
                "anchor_point": 1.0,
                "anchor_value": 0.08279169558999999
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 2.0,
                "anchor_value": 0.15208786289999998
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 3.0,
                "anchor_value": 0.22606802550000002
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 4.0,
                "anchor_value": 0.30519685399999996
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 5.0,
                "anchor_value": 0.3898501007
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 6.0,
                "anchor_value": 0.46571476100000003
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 7.0,
                "anchor_value": 0.5437966463
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 8.0,
                "anchor_value": 0.6254869003
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 9.0,
                "anchor_value": 0.7070824991
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 10.0,
                "anchor_value": 0.7952064343
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 11.0,
                "anchor_value": 0.8861585502
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 12.0,
                "anchor_value": 1.0
            }
        ],
        "traditional": [
            {
                "anchor_type": "month_of_year",
                "anchor_point": 1,
                "anchor_value": 0.0424
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 2,
                "anchor_value": 0.103
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 3,
                "anchor_value": 0.203
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 4,
                "anchor_value": 0.3152
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 5,
                "anchor_value": 0.4139
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 6,
                "anchor_value": 0.4776
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 7,
                "anchor_value": 0.5321
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 8,
                "anchor_value": 0.5897
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 9,
                "anchor_value": 0.6715
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 10,
                "anchor_value": 0.7836
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 11,
                "anchor_value": 0.9018
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 12,
                "anchor_value": 1.0
            }
        ],
        "traditional_brand": [
            {
                "anchor_type": "month_of_year",
                "anchor_point": 1.0,
                "anchor_value": 0.01817698039
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 2.0,
                "anchor_value": 0.12266991029999999
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 3.0,
                "anchor_value": 0.2905199939
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 4.0,
                "anchor_value": 0.39478485630000004
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 5.0,
                "anchor_value": 0.5243728143999999
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 6.0,
                "anchor_value": 0.5496122852
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 7.0,
                "anchor_value": 0.5708757792
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 8.0,
                "anchor_value": 0.5895012924
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 9.0,
                "anchor_value": 0.6574882165
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 10.0,
                "anchor_value": 0.8245172570999999
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 11.0,
                "anchor_value": 0.9510339059999999
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 12.0,
                "anchor_value": 1.0
            }
        ],
        "traditional_distributor": [
            {
                "anchor_type": "month_of_year",
                "anchor_point": 1.0,
                "anchor_value": 0.024172754080000004
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 2.0,
                "anchor_value": 0.1028894152
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 3.0,
                "anchor_value": 0.20738941519999998
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 4.0,
                "anchor_value": 0.3296613436
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 5.0,
                "anchor_value": 0.4090613436
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 6.0,
                "anchor_value": 0.4526022165
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 7.0,
                "anchor_value": 0.4746022165
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 8.0,
                "anchor_value": 0.5077076993999999
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 9.0,
                "anchor_value": 0.5924076993999999
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 10.0,
                "anchor_value": 0.7364076994
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 11.0,
                "anchor_value": 0.9042076994
            },
            {
                "anchor_type": "month_of_year",
                "anchor_point": 12.0,
                "anchor_value": 1.0
            }
        ],
        "growth": [
            {
                "anchor_value": 0.0424,
                "anchor_type": "month_of_year",
                "anchor_point": 1.0
            },
            {
                "anchor_value": 0.103,
                "anchor_type": "month_of_year",
                "anchor_point": 2.0
            },
            {
                "anchor_value": 0.203,
                "anchor_type": "month_of_year",
                "anchor_point": 3.0
            },
            {
                "anchor_value": 0.3151,
                "anchor_type": "month_of_year",
                "anchor_point": 4.0
            },
            {
                "anchor_value": 0.4139,
                "anchor_type": "month_of_year",
                "anchor_point": 5.0
            },
            {
                "anchor_value": 0.4775,
                "anchor_type": "month_of_year",
                "anchor_point": 6.0
            },
            {
                "anchor_value": 0.532,
                "anchor_type": "month_of_year",
                "anchor_point": 7.0
            },
            {
                "anchor_value": 0.5896,
                "anchor_type": "month_of_year",
                "anchor_point": 8.0
            },
            {
                "anchor_value": 0.6714,
                "anchor_type": "month_of_year",
                "anchor_point": 9.0
            },
            {
                "anchor_value": 0.7836,
                "anchor_type": "month_of_year",
                "anchor_point": 10.0
            },
            {
                "anchor_value": 0.9018,
                "anchor_type": "month_of_year",
                "anchor_point": 11.0
            },
            {
                "anchor_value": 1.0,
                "anchor_type": "month_of_year",
                "anchor_point": 12.0
            }
        ],
        "steady": [
            {
                "anchor_value": 0.0424,
                "anchor_type": "month_of_year",
                "anchor_point": 1.0
            },
            {
                "anchor_value": 0.103,
                "anchor_type": "month_of_year",
                "anchor_point": 2.0
            },
            {
                "anchor_value": 0.203,
                "anchor_type": "month_of_year",
                "anchor_point": 3.0
            },
            {
                "anchor_value": 0.3151,
                "anchor_type": "month_of_year",
                "anchor_point": 4.0
            },
            {
                "anchor_value": 0.4139,
                "anchor_type": "month_of_year",
                "anchor_point": 5.0
            },
            {
                "anchor_value": 0.4775,
                "anchor_type": "month_of_year",
                "anchor_point": 6.0
            },
            {
                "anchor_value": 0.532,
                "anchor_type": "month_of_year",
                "anchor_point": 7.0
            },
            {
                "anchor_value": 0.5896,
                "anchor_type": "month_of_year",
                "anchor_point": 8.0
            },
            {
                "anchor_value": 0.6714,
                "anchor_type": "month_of_year",
                "anchor_point": 9.0
            },
            {
                "anchor_value": 0.7836,
                "anchor_type": "month_of_year",
                "anchor_point": 10.0
            },
            {
                "anchor_value": 0.9018,
                "anchor_type": "month_of_year",
                "anchor_point": 11.0
            },
            {
                "anchor_value": 1.0,
                "anchor_type": "month_of_year",
                "anchor_point": 12.0
            }
        ],
        "variable": [
            {
                "anchor_value": 0.0424,
                "anchor_type": "month_of_year",
                "anchor_point": 1.0
            },
            {
                "anchor_value": 0.103,
                "anchor_type": "month_of_year",
                "anchor_point": 2.0
            },
            {
                "anchor_value": 0.203,
                "anchor_type": "month_of_year",
                "anchor_point": 3.0
            },
            {
                "anchor_value": 0.3151,
                "anchor_type": "month_of_year",
                "anchor_point": 4.0
            },
            {
                "anchor_value": 0.4139,
                "anchor_type": "month_of_year",
                "anchor_point": 5.0
            },
            {
                "anchor_value": 0.4775,
                "anchor_type": "month_of_year",
                "anchor_point": 6.0
            },
            {
                "anchor_value": 0.532,
                "anchor_type": "month_of_year",
                "anchor_point": 7.0
            },
            {
                "anchor_value": 0.5896,
                "anchor_type": "month_of_year",
                "anchor_point": 8.0
            },
            {
                "anchor_value": 0.6714,
                "anchor_type": "month_of_year",
                "anchor_point": 9.0
            },
            {
                "anchor_value": 0.7836,
                "anchor_type": "month_of_year",
                "anchor_point": 10.0
            },
            {
                "anchor_value": 0.9018,
                "anchor_type": "month_of_year",
                "anchor_point": 11.0
            },
            {
                "anchor_value": 1.0,
                "anchor_type": "month_of_year",
                "anchor_point": 12.0
            }
        ],
        "kv_standard": [
            {'anchor_type': 'month_of_year', 'anchor_point': 1.0, 'anchor_value': 7.8},
            {'anchor_type': 'month_of_year', 'anchor_point': 2.0, 'anchor_value': 15.11},
            {'anchor_type': 'month_of_year', 'anchor_point': 3.0, 'anchor_value': 23.66},
            {'anchor_type': 'month_of_year', 'anchor_point': 4.0, 'anchor_value': 32.99},
            {'anchor_type': 'month_of_year', 'anchor_point': 5.0, 'anchor_value': 42.14},
            {'anchor_type': 'month_of_year', 'anchor_point': 6.0, 'anchor_value': 50.89},
            {'anchor_type': 'month_of_year', 'anchor_point': 7.0, 'anchor_value': 59.74},
            {'anchor_type': 'month_of_year', 'anchor_point': 8.0, 'anchor_value': 67.79},
            {'anchor_type': 'month_of_year', 'anchor_point': 9.0, 'anchor_value': 75.74},
            {'anchor_type': 'month_of_year', 'anchor_point': 10.0, 'anchor_value': 83.74},
            {'anchor_type': 'month_of_year', 'anchor_point': 11.0, 'anchor_value': 91.95},
            {'anchor_type': 'month_of_year', 'anchor_point': 12.0, 'anchor_value': 100.0}
        ]
    },
    "week": {
        "modern_brand": [
            {
                "anchor_type": "week_of_year",
                "anchor_point": 1,
                "anchor_value": 0.0164
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 2,
                "anchor_value": 0.0336
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 3,
                "anchor_value": 0.0562
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 4,
                "anchor_value": 0.0728
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 5,
                "anchor_value": 0.0914
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 6,
                "anchor_value": 0.111
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 7,
                "anchor_value": 0.1297
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 8,
                "anchor_value": 0.1459
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 9,
                "anchor_value": 0.1656
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 10,
                "anchor_value": 0.1837
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 11,
                "anchor_value": 0.2055
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 12,
                "anchor_value": 0.2252
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 13,
                "anchor_value": 0.2445
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 14,
                "anchor_value": 0.2636
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 15,
                "anchor_value": 0.2834
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 16,
                "anchor_value": 0.3017
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 17,
                "anchor_value": 0.3214
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 18,
                "anchor_value": 0.3442
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 19,
                "anchor_value": 0.3633
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 20,
                "anchor_value": 0.3824
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 21,
                "anchor_value": 0.4022
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 22,
                "anchor_value": 0.4205
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 23,
                "anchor_value": 0.4429
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 24,
                "anchor_value": 0.4661
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 25,
                "anchor_value": 0.4875
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 26,
                "anchor_value": 0.5098
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 27,
                "anchor_value": 0.5282
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 28,
                "anchor_value": 0.5451
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 29,
                "anchor_value": 0.5624
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 30,
                "anchor_value": 0.5807
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 31,
                "anchor_value": 0.5999
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 32,
                "anchor_value": 0.6173
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 33,
                "anchor_value": 0.6329
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 34,
                "anchor_value": 0.6507
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 35,
                "anchor_value": 0.6683
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 36,
                "anchor_value": 0.6869
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 37,
                "anchor_value": 0.7091
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 38,
                "anchor_value": 0.7292
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 39,
                "anchor_value": 0.7487
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 40,
                "anchor_value": 0.7669
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 41,
                "anchor_value": 0.7849
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 42,
                "anchor_value": 0.8034
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 43,
                "anchor_value": 0.8214
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 44,
                "anchor_value": 0.8398
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 45,
                "anchor_value": 0.8582
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 46,
                "anchor_value": 0.8802
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 47,
                "anchor_value": 0.8971
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 48,
                "anchor_value": 0.918
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 49,
                "anchor_value": 0.9386
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 50,
                "anchor_value": 0.9631
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 51,
                "anchor_value": 0.984
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 52,
                "anchor_value": 1.0
            }
        ],
        "modern_distributor": [
            {
                "anchor_type": "week_of_year",
                "anchor_point": 1,
                "anchor_value": 0.0184
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 2,
                "anchor_value": 0.0349
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 3,
                "anchor_value": 0.051
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 4,
                "anchor_value": 0.068
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 5,
                "anchor_value": 0.0853
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 6,
                "anchor_value": 0.1067
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 7,
                "anchor_value": 0.1254
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 8,
                "anchor_value": 0.1434
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 9,
                "anchor_value": 0.1626
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 10,
                "anchor_value": 0.1853
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 11,
                "anchor_value": 0.206
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 12,
                "anchor_value": 0.2246
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 13,
                "anchor_value": 0.2458
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 14,
                "anchor_value": 0.265
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 15,
                "anchor_value": 0.2872
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 16,
                "anchor_value": 0.3071
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 17,
                "anchor_value": 0.3259
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 18,
                "anchor_value": 0.3428
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 19,
                "anchor_value": 0.363
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 20,
                "anchor_value": 0.3812
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 21,
                "anchor_value": 0.3985
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 22,
                "anchor_value": 0.4126
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 23,
                "anchor_value": 0.4328
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 24,
                "anchor_value": 0.4517
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 25,
                "anchor_value": 0.4679
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 26,
                "anchor_value": 0.4842
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 27,
                "anchor_value": 0.4972
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 28,
                "anchor_value": 0.5113
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 29,
                "anchor_value": 0.5286
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 30,
                "anchor_value": 0.543
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 31,
                "anchor_value": 0.5575
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 32,
                "anchor_value": 0.5731
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 33,
                "anchor_value": 0.588
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 34,
                "anchor_value": 0.6028
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 35,
                "anchor_value": 0.6198
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 36,
                "anchor_value": 0.634
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 37,
                "anchor_value": 0.6551
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 38,
                "anchor_value": 0.673
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 39,
                "anchor_value": 0.6904
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 40,
                "anchor_value": 0.711
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 41,
                "anchor_value": 0.7298
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 42,
                "anchor_value": 0.7506
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 43,
                "anchor_value": 0.7709
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 44,
                "anchor_value": 0.7922
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 45,
                "anchor_value": 0.8196
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 46,
                "anchor_value": 0.8441
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 47,
                "anchor_value": 0.8717
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 48,
                "anchor_value": 0.8947
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 49,
                "anchor_value": 0.9253
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 50,
                "anchor_value": 0.9551
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 51,
                "anchor_value": 0.9868
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 52,
                "anchor_value": 1.0
            }
        ],
        "traditional_brand": [
            {
                "anchor_type": "week_of_year",
                "anchor_point": 1,
                "anchor_value": 0.004
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 2,
                "anchor_value": 0.0094
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 3,
                "anchor_value": 0.0135
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 4,
                "anchor_value": 0.0229
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 5,
                "anchor_value": 0.0305
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 6,
                "anchor_value": 0.0478
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 7,
                "anchor_value": 0.0818
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 8,
                "anchor_value": 0.1018
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 9,
                "anchor_value": 0.1231
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 10,
                "anchor_value": 0.1555
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 11,
                "anchor_value": 0.1838
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 12,
                "anchor_value": 0.2136
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 13,
                "anchor_value": 0.2399
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 14,
                "anchor_value": 0.2768
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 15,
                "anchor_value": 0.3141
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 16,
                "anchor_value": 0.3341
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 17,
                "anchor_value": 0.3512
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 18,
                "anchor_value": 0.3673
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 19,
                "anchor_value": 0.4038
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 20,
                "anchor_value": 0.4302
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 21,
                "anchor_value": 0.4416
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 22,
                "anchor_value": 0.4496
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 23,
                "anchor_value": 0.4613
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 24,
                "anchor_value": 0.4774
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 25,
                "anchor_value": 0.488
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 26,
                "anchor_value": 0.4924
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 27,
                "anchor_value": 0.4974
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 28,
                "anchor_value": 0.5042
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 29,
                "anchor_value": 0.5089
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 30,
                "anchor_value": 0.5141
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 31,
                "anchor_value": 0.5186
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 32,
                "anchor_value": 0.5261
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 33,
                "anchor_value": 0.5369
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 34,
                "anchor_value": 0.541
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 35,
                "anchor_value": 0.5495
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 36,
                "anchor_value": 0.5553
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 37,
                "anchor_value": 0.5791
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 38,
                "anchor_value": 0.5958
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 39,
                "anchor_value": 0.6124
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 40,
                "anchor_value": 0.6369
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 41,
                "anchor_value": 0.6727
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 42,
                "anchor_value": 0.7099
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 43,
                "anchor_value": 0.7391
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 44,
                "anchor_value": 0.7726
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 45,
                "anchor_value": 0.8254
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 46,
                "anchor_value": 0.8744
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 47,
                "anchor_value": 0.8854
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 48,
                "anchor_value": 0.9109
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 49,
                "anchor_value": 0.9385
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 50,
                "anchor_value": 0.9823
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 51,
                "anchor_value": 0.9965
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 52,
                "anchor_value": 1.0
            }
        ],
        "traditional_distributor": [
            {
                "anchor_type": "week_of_year",
                "anchor_point": 1,
                "anchor_value": 0.0044
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 2,
                "anchor_value": 0.0097
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 3,
                "anchor_value": 0.0152
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 4,
                "anchor_value": 0.0228
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 5,
                "anchor_value": 0.03
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 6,
                "anchor_value": 0.0489
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 7,
                "anchor_value": 0.0808
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 8,
                "anchor_value": 0.0978
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 9,
                "anchor_value": 0.1177
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 10,
                "anchor_value": 0.1479
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 11,
                "anchor_value": 0.1779
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 12,
                "anchor_value": 0.2042
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 13,
                "anchor_value": 0.2291
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 14,
                "anchor_value": 0.2663
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 15,
                "anchor_value": 0.3025
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 16,
                "anchor_value": 0.3239
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 17,
                "anchor_value": 0.3397
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 18,
                "anchor_value": 0.356
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 19,
                "anchor_value": 0.3877
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 20,
                "anchor_value": 0.4135
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 21,
                "anchor_value": 0.4248
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 22,
                "anchor_value": 0.4322
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 23,
                "anchor_value": 0.4439
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 24,
                "anchor_value": 0.4579
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 25,
                "anchor_value": 0.4672
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 26,
                "anchor_value": 0.4753
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 27,
                "anchor_value": 0.4798
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 28,
                "anchor_value": 0.4857
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 29,
                "anchor_value": 0.49
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 30,
                "anchor_value": 0.4951
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 31,
                "anchor_value": 0.4999
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 32,
                "anchor_value": 0.507
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 33,
                "anchor_value": 0.5178
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 34,
                "anchor_value": 0.5229
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 35,
                "anchor_value": 0.5311
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 36,
                "anchor_value": 0.5406
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 37,
                "anchor_value": 0.5643
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 38,
                "anchor_value": 0.5844
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 39,
                "anchor_value": 0.6016
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 40,
                "anchor_value": 0.6241
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 41,
                "anchor_value": 0.6581
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 42,
                "anchor_value": 0.6906
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 43,
                "anchor_value": 0.7192
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 44,
                "anchor_value": 0.7558
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 45,
                "anchor_value": 0.8104
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 46,
                "anchor_value": 0.8616
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 47,
                "anchor_value": 0.8811
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 48,
                "anchor_value": 0.901
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 49,
                "anchor_value": 0.9322
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 50,
                "anchor_value": 0.9761
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 51,
                "anchor_value": 0.9954
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 52,
                "anchor_value": 1.0
            }
        ],
        "growth": [
            {
                "anchor_value": 0.0045,
                "anchor_type": "week_of_year",
                "anchor_point": 1.0
            },
            {
                "anchor_value": 0.0095,
                "anchor_type": "week_of_year",
                "anchor_point": 2.0
            },
            {
                "anchor_value": 0.015,
                "anchor_type": "week_of_year",
                "anchor_point": 3.0
            },
            {
                "anchor_value": 0.0215,
                "anchor_type": "week_of_year",
                "anchor_point": 4.0
            },
            {
                "anchor_value": 0.028998,
                "anchor_type": "week_of_year",
                "anchor_point": 5.0
            },
            {
                "anchor_value": 0.0465,
                "anchor_type": "week_of_year",
                "anchor_point": 6.0
            },
            {
                "anchor_value": 0.0765,
                "anchor_type": "week_of_year",
                "anchor_point": 7.0
            },
            {
                "anchor_value": 0.0925,
                "anchor_type": "week_of_year",
                "anchor_point": 8.0
            },
            {
                "anchor_value": 0.111,
                "anchor_type": "week_of_year",
                "anchor_point": 9.0
            },
            {
                "anchor_value": 0.1385,
                "anchor_type": "week_of_year",
                "anchor_point": 10.0
            },
            {
                "anchor_value": 0.1665,
                "anchor_type": "week_of_year",
                "anchor_point": 11.0
            },
            {
                "anchor_value": 0.1915,
                "anchor_type": "week_of_year",
                "anchor_point": 12.0
            },
            {
                "anchor_value": 0.2155,
                "anchor_type": "week_of_year",
                "anchor_point": 13.0
            },
            {
                "anchor_value": 0.252,
                "anchor_type": "week_of_year",
                "anchor_point": 14.0
            },
            {
                "anchor_value": 0.2875,
                "anchor_type": "week_of_year",
                "anchor_point": 15.0
            },
            {
                "anchor_value": 0.31,
                "anchor_type": "week_of_year",
                "anchor_point": 16.0
            },
            {
                "anchor_value": 0.327,
                "anchor_type": "week_of_year",
                "anchor_point": 17.0
            },
            {
                "anchor_value": 0.3435,
                "anchor_type": "week_of_year",
                "anchor_point": 18.0
            },
            {
                "anchor_value": 0.37355,
                "anchor_type": "week_of_year",
                "anchor_point": 19.0
            },
            {
                "anchor_value": 0.4005001,
                "anchor_type": "week_of_year",
                "anchor_point": 20.0
            },
            {
                "anchor_value": 0.4131,
                "anchor_type": "week_of_year",
                "anchor_point": 21.0
            },
            {
                "anchor_value": 0.4245001,
                "anchor_type": "week_of_year",
                "anchor_point": 22.0
            },
            {
                "anchor_value": 0.4351,
                "anchor_type": "week_of_year",
                "anchor_point": 23.0
            },
            {
                "anchor_value": 0.4451,
                "anchor_type": "week_of_year",
                "anchor_point": 24.0
            },
            {
                "anchor_value": 0.4545001,
                "anchor_type": "week_of_year",
                "anchor_point": 25.0
            },
            {
                "anchor_value": 0.46313,
                "anchor_type": "week_of_year",
                "anchor_point": 26.0
            },
            {
                "anchor_value": 0.46950014,
                "anchor_type": "week_of_year",
                "anchor_point": 27.0
            },
            {
                "anchor_value": 0.47650015,
                "anchor_type": "week_of_year",
                "anchor_point": 28.0
            },
            {
                "anchor_value": 0.48215,
                "anchor_type": "week_of_year",
                "anchor_point": 29.0
            },
            {
                "anchor_value": 0.48816,
                "anchor_type": "week_of_year",
                "anchor_point": 30.0
            },
            {
                "anchor_value": 0.49350016,
                "anchor_type": "week_of_year",
                "anchor_point": 31.0
            },
            {
                "anchor_value": 0.5011,
                "anchor_type": "week_of_year",
                "anchor_point": 32.0
            },
            {
                "anchor_value": 0.5105001,
                "anchor_type": "week_of_year",
                "anchor_point": 33.0
            },
            {
                "anchor_value": 0.5165001,
                "anchor_type": "week_of_year",
                "anchor_point": 34.0
            },
            {
                "anchor_value": 0.5265001,
                "anchor_type": "week_of_year",
                "anchor_point": 35.0
            },
            {
                "anchor_value": 0.539,
                "anchor_type": "week_of_year",
                "anchor_point": 36.0
            },
            {
                "anchor_value": 0.5631,
                "anchor_type": "week_of_year",
                "anchor_point": 37.0
            },
            {
                "anchor_value": 0.5811,
                "anchor_type": "week_of_year",
                "anchor_point": 38.0
            },
            {
                "anchor_value": 0.6011,
                "anchor_type": "week_of_year",
                "anchor_point": 39.0
            },
            {
                "anchor_value": 0.6235,
                "anchor_type": "week_of_year",
                "anchor_point": 40.0
            },
            {
                "anchor_value": 0.656,
                "anchor_type": "week_of_year",
                "anchor_point": 41.0
            },
            {
                "anchor_value": 0.6895,
                "anchor_type": "week_of_year",
                "anchor_point": 42.0
            },
            {
                "anchor_value": 0.7175,
                "anchor_type": "week_of_year",
                "anchor_point": 43.0
            },
            {
                "anchor_value": 0.754,
                "anchor_type": "week_of_year",
                "anchor_point": 44.0
            },
            {
                "anchor_value": 0.8075,
                "anchor_type": "week_of_year",
                "anchor_point": 45.0
            },
            {
                "anchor_value": 0.8575,
                "anchor_type": "week_of_year",
                "anchor_point": 46.0
            },
            {
                "anchor_value": 0.88,
                "anchor_type": "week_of_year",
                "anchor_point": 47.0
            },
            {
                "anchor_value": 0.899,
                "anchor_type": "week_of_year",
                "anchor_point": 48.0
            },
            {
                "anchor_value": 0.931,
                "anchor_type": "week_of_year",
                "anchor_point": 49.0
            },
            {
                "anchor_value": 0.9745,
                "anchor_type": "week_of_year",
                "anchor_point": 50.0
            },
            {
                "anchor_value": 0.9945,
                "anchor_type": "week_of_year",
                "anchor_point": 51.0
            },
            {
                "anchor_value": 1.0,
                "anchor_type": "week_of_year",
                "anchor_point": 52.0
            }
        ],
        "steady": [
            {
                "anchor_value": 0.0045,
                "anchor_type": "week_of_year",
                "anchor_point": 1.0
            },
            {
                "anchor_value": 0.0095,
                "anchor_type": "week_of_year",
                "anchor_point": 2.0
            },
            {
                "anchor_value": 0.015,
                "anchor_type": "week_of_year",
                "anchor_point": 3.0
            },
            {
                "anchor_value": 0.0215,
                "anchor_type": "week_of_year",
                "anchor_point": 4.0
            },
            {
                "anchor_value": 0.028998,
                "anchor_type": "week_of_year",
                "anchor_point": 5.0
            },
            {
                "anchor_value": 0.0465,
                "anchor_type": "week_of_year",
                "anchor_point": 6.0
            },
            {
                "anchor_value": 0.0765,
                "anchor_type": "week_of_year",
                "anchor_point": 7.0
            },
            {
                "anchor_value": 0.0925,
                "anchor_type": "week_of_year",
                "anchor_point": 8.0
            },
            {
                "anchor_value": 0.111,
                "anchor_type": "week_of_year",
                "anchor_point": 9.0
            },
            {
                "anchor_value": 0.1385,
                "anchor_type": "week_of_year",
                "anchor_point": 10.0
            },
            {
                "anchor_value": 0.1665,
                "anchor_type": "week_of_year",
                "anchor_point": 11.0
            },
            {
                "anchor_value": 0.1915,
                "anchor_type": "week_of_year",
                "anchor_point": 12.0
            },
            {
                "anchor_value": 0.2155,
                "anchor_type": "week_of_year",
                "anchor_point": 13.0
            },
            {
                "anchor_value": 0.252,
                "anchor_type": "week_of_year",
                "anchor_point": 14.0
            },
            {
                "anchor_value": 0.2875,
                "anchor_type": "week_of_year",
                "anchor_point": 15.0
            },
            {
                "anchor_value": 0.31,
                "anchor_type": "week_of_year",
                "anchor_point": 16.0
            },
            {
                "anchor_value": 0.327,
                "anchor_type": "week_of_year",
                "anchor_point": 17.0
            },
            {
                "anchor_value": 0.3435,
                "anchor_type": "week_of_year",
                "anchor_point": 18.0
            },
            {
                "anchor_value": 0.37355,
                "anchor_type": "week_of_year",
                "anchor_point": 19.0
            },
            {
                "anchor_value": 0.4005001,
                "anchor_type": "week_of_year",
                "anchor_point": 20.0
            },
            {
                "anchor_value": 0.4131,
                "anchor_type": "week_of_year",
                "anchor_point": 21.0
            },
            {
                "anchor_value": 0.4245001,
                "anchor_type": "week_of_year",
                "anchor_point": 22.0
            },
            {
                "anchor_value": 0.4351,
                "anchor_type": "week_of_year",
                "anchor_point": 23.0
            },
            {
                "anchor_value": 0.4451,
                "anchor_type": "week_of_year",
                "anchor_point": 24.0
            },
            {
                "anchor_value": 0.4545001,
                "anchor_type": "week_of_year",
                "anchor_point": 25.0
            },
            {
                "anchor_value": 0.46313,
                "anchor_type": "week_of_year",
                "anchor_point": 26.0
            },
            {
                "anchor_value": 0.46950014,
                "anchor_type": "week_of_year",
                "anchor_point": 27.0
            },
            {
                "anchor_value": 0.47650015,
                "anchor_type": "week_of_year",
                "anchor_point": 28.0
            },
            {
                "anchor_value": 0.48215,
                "anchor_type": "week_of_year",
                "anchor_point": 29.0
            },
            {
                "anchor_value": 0.48816,
                "anchor_type": "week_of_year",
                "anchor_point": 30.0
            },
            {
                "anchor_value": 0.49350016,
                "anchor_type": "week_of_year",
                "anchor_point": 31.0
            },
            {
                "anchor_value": 0.5011,
                "anchor_type": "week_of_year",
                "anchor_point": 32.0
            },
            {
                "anchor_value": 0.5105001,
                "anchor_type": "week_of_year",
                "anchor_point": 33.0
            },
            {
                "anchor_value": 0.5165001,
                "anchor_type": "week_of_year",
                "anchor_point": 34.0
            },
            {
                "anchor_value": 0.5265001,
                "anchor_type": "week_of_year",
                "anchor_point": 35.0
            },
            {
                "anchor_value": 0.539,
                "anchor_type": "week_of_year",
                "anchor_point": 36.0
            },
            {
                "anchor_value": 0.5631,
                "anchor_type": "week_of_year",
                "anchor_point": 37.0
            },
            {
                "anchor_value": 0.5811,
                "anchor_type": "week_of_year",
                "anchor_point": 38.0
            },
            {
                "anchor_value": 0.6011,
                "anchor_type": "week_of_year",
                "anchor_point": 39.0
            },
            {
                "anchor_value": 0.6235,
                "anchor_type": "week_of_year",
                "anchor_point": 40.0
            },
            {
                "anchor_value": 0.656,
                "anchor_type": "week_of_year",
                "anchor_point": 41.0
            },
            {
                "anchor_value": 0.6895,
                "anchor_type": "week_of_year",
                "anchor_point": 42.0
            },
            {
                "anchor_value": 0.7175,
                "anchor_type": "week_of_year",
                "anchor_point": 43.0
            },
            {
                "anchor_value": 0.754,
                "anchor_type": "week_of_year",
                "anchor_point": 44.0
            },
            {
                "anchor_value": 0.8075,
                "anchor_type": "week_of_year",
                "anchor_point": 45.0
            },
            {
                "anchor_value": 0.8575,
                "anchor_type": "week_of_year",
                "anchor_point": 46.0
            },
            {
                "anchor_value": 0.88,
                "anchor_type": "week_of_year",
                "anchor_point": 47.0
            },
            {
                "anchor_value": 0.899,
                "anchor_type": "week_of_year",
                "anchor_point": 48.0
            },
            {
                "anchor_value": 0.931,
                "anchor_type": "week_of_year",
                "anchor_point": 49.0
            },
            {
                "anchor_value": 0.9745,
                "anchor_type": "week_of_year",
                "anchor_point": 50.0
            },
            {
                "anchor_value": 0.9945,
                "anchor_type": "week_of_year",
                "anchor_point": 51.0
            },
            {
                "anchor_value": 1.0,
                "anchor_type": "week_of_year",
                "anchor_point": 52.0
            }
        ],
        "variable": [
            {
                "anchor_value": 0.0045,
                "anchor_type": "week_of_year",
                "anchor_point": 1.0
            },
            {
                "anchor_value": 0.0095,
                "anchor_type": "week_of_year",
                "anchor_point": 2.0
            },
            {
                "anchor_value": 0.015,
                "anchor_type": "week_of_year",
                "anchor_point": 3.0
            },
            {
                "anchor_value": 0.0215,
                "anchor_type": "week_of_year",
                "anchor_point": 4.0
            },
            {
                "anchor_value": 0.028998,
                "anchor_type": "week_of_year",
                "anchor_point": 5.0
            },
            {
                "anchor_value": 0.0465,
                "anchor_type": "week_of_year",
                "anchor_point": 6.0
            },
            {
                "anchor_value": 0.0765,
                "anchor_type": "week_of_year",
                "anchor_point": 7.0
            },
            {
                "anchor_value": 0.0925,
                "anchor_type": "week_of_year",
                "anchor_point": 8.0
            },
            {
                "anchor_value": 0.111,
                "anchor_type": "week_of_year",
                "anchor_point": 9.0
            },
            {
                "anchor_value": 0.1385,
                "anchor_type": "week_of_year",
                "anchor_point": 10.0
            },
            {
                "anchor_value": 0.1665,
                "anchor_type": "week_of_year",
                "anchor_point": 11.0
            },
            {
                "anchor_value": 0.1915,
                "anchor_type": "week_of_year",
                "anchor_point": 12.0
            },
            {
                "anchor_value": 0.2155,
                "anchor_type": "week_of_year",
                "anchor_point": 13.0
            },
            {
                "anchor_value": 0.252,
                "anchor_type": "week_of_year",
                "anchor_point": 14.0
            },
            {
                "anchor_value": 0.2875,
                "anchor_type": "week_of_year",
                "anchor_point": 15.0
            },
            {
                "anchor_value": 0.31,
                "anchor_type": "week_of_year",
                "anchor_point": 16.0
            },
            {
                "anchor_value": 0.327,
                "anchor_type": "week_of_year",
                "anchor_point": 17.0
            },
            {
                "anchor_value": 0.3435,
                "anchor_type": "week_of_year",
                "anchor_point": 18.0
            },
            {
                "anchor_value": 0.37355,
                "anchor_type": "week_of_year",
                "anchor_point": 19.0
            },
            {
                "anchor_value": 0.4005001,
                "anchor_type": "week_of_year",
                "anchor_point": 20.0
            },
            {
                "anchor_value": 0.4131,
                "anchor_type": "week_of_year",
                "anchor_point": 21.0
            },
            {
                "anchor_value": 0.4245001,
                "anchor_type": "week_of_year",
                "anchor_point": 22.0
            },
            {
                "anchor_value": 0.4351,
                "anchor_type": "week_of_year",
                "anchor_point": 23.0
            },
            {
                "anchor_value": 0.4451,
                "anchor_type": "week_of_year",
                "anchor_point": 24.0
            },
            {
                "anchor_value": 0.4545001,
                "anchor_type": "week_of_year",
                "anchor_point": 25.0
            },
            {
                "anchor_value": 0.46313,
                "anchor_type": "week_of_year",
                "anchor_point": 26.0
            },
            {
                "anchor_value": 0.46950014,
                "anchor_type": "week_of_year",
                "anchor_point": 27.0
            },
            {
                "anchor_value": 0.47650015,
                "anchor_type": "week_of_year",
                "anchor_point": 28.0
            },
            {
                "anchor_value": 0.48215,
                "anchor_type": "week_of_year",
                "anchor_point": 29.0
            },
            {
                "anchor_value": 0.48816,
                "anchor_type": "week_of_year",
                "anchor_point": 30.0
            },
            {
                "anchor_value": 0.49350016,
                "anchor_type": "week_of_year",
                "anchor_point": 31.0
            },
            {
                "anchor_value": 0.5011,
                "anchor_type": "week_of_year",
                "anchor_point": 32.0
            },
            {
                "anchor_value": 0.5105001,
                "anchor_type": "week_of_year",
                "anchor_point": 33.0
            },
            {
                "anchor_value": 0.5165001,
                "anchor_type": "week_of_year",
                "anchor_point": 34.0
            },
            {
                "anchor_value": 0.5265001,
                "anchor_type": "week_of_year",
                "anchor_point": 35.0
            },
            {
                "anchor_value": 0.539,
                "anchor_type": "week_of_year",
                "anchor_point": 36.0
            },
            {
                "anchor_value": 0.5631,
                "anchor_type": "week_of_year",
                "anchor_point": 37.0
            },
            {
                "anchor_value": 0.5811,
                "anchor_type": "week_of_year",
                "anchor_point": 38.0
            },
            {
                "anchor_value": 0.6011,
                "anchor_type": "week_of_year",
                "anchor_point": 39.0
            },
            {
                "anchor_value": 0.6235,
                "anchor_type": "week_of_year",
                "anchor_point": 40.0
            },
            {
                "anchor_value": 0.656,
                "anchor_type": "week_of_year",
                "anchor_point": 41.0
            },
            {
                "anchor_value": 0.6895,
                "anchor_type": "week_of_year",
                "anchor_point": 42.0
            },
            {
                "anchor_value": 0.7175,
                "anchor_type": "week_of_year",
                "anchor_point": 43.0
            },
            {
                "anchor_value": 0.754,
                "anchor_type": "week_of_year",
                "anchor_point": 44.0
            },
            {
                "anchor_value": 0.8075,
                "anchor_type": "week_of_year",
                "anchor_point": 45.0
            },
            {
                "anchor_value": 0.8575,
                "anchor_type": "week_of_year",
                "anchor_point": 46.0
            },
            {
                "anchor_value": 0.88,
                "anchor_type": "week_of_year",
                "anchor_point": 47.0
            },
            {
                "anchor_value": 0.899,
                "anchor_type": "week_of_year",
                "anchor_point": 48.0
            },
            {
                "anchor_value": 0.931,
                "anchor_type": "week_of_year",
                "anchor_point": 49.0
            },
            {
                "anchor_value": 0.9745,
                "anchor_type": "week_of_year",
                "anchor_point": 50.0
            },
            {
                "anchor_value": 0.9945,
                "anchor_type": "week_of_year",
                "anchor_point": 51.0
            },
            {
                "anchor_value": 1.0,
                "anchor_type": "week_of_year",
                "anchor_point": 52.0
            }
        ],
        "kv_standard": [
            {'anchor_type': 'week_of_year', 'anchor_point': 1.0, 'anchor_value': 1.7},
            {'anchor_type': 'week_of_year', 'anchor_point': 2.0, 'anchor_value': 3.47},
            {'anchor_type': 'week_of_year', 'anchor_point': 3.0, 'anchor_value': 5.28},
            {'anchor_type': 'week_of_year', 'anchor_point': 4.0, 'anchor_value': 7.07},
            {'anchor_type': 'week_of_year', 'anchor_point': 5.0, 'anchor_value': 8.84},
            {'anchor_type': 'week_of_year', 'anchor_point': 6.0, 'anchor_value': 10.58},
            {'anchor_type': 'week_of_year', 'anchor_point': 7.0, 'anchor_value': 12.29},
            {'anchor_type': 'week_of_year', 'anchor_point': 8.0, 'anchor_value': 14.04},
            {'anchor_type': 'week_of_year', 'anchor_point': 9.0, 'anchor_value': 15.84},
            {'anchor_type': 'week_of_year', 'anchor_point': 10.0, 'anchor_value': 17.68},
            {'anchor_type': 'week_of_year', 'anchor_point': 11.0, 'anchor_value': 19.55},
            {'anchor_type': 'week_of_year', 'anchor_point': 12.0, 'anchor_value': 21.45},
            {'anchor_type': 'week_of_year', 'anchor_point': 13.0, 'anchor_value': 23.4},
            {'anchor_type': 'week_of_year', 'anchor_point': 14.0, 'anchor_value': 25.59},
            {'anchor_type': 'week_of_year', 'anchor_point': 15.0, 'anchor_value': 28.01},
            {'anchor_type': 'week_of_year', 'anchor_point': 16.0, 'anchor_value': 30.52},
            {'anchor_type': 'week_of_year', 'anchor_point': 17.0, 'anchor_value': 32.98},
            {'anchor_type': 'week_of_year', 'anchor_point': 18.0, 'anchor_value': 35.41},
            {'anchor_type': 'week_of_year', 'anchor_point': 19.0, 'anchor_value': 37.79},
            {'anchor_type': 'week_of_year', 'anchor_point': 20.0, 'anchor_value': 40.13},
            {'anchor_type': 'week_of_year', 'anchor_point': 21.0, 'anchor_value': 42.41},
            {'anchor_type': 'week_of_year', 'anchor_point': 22.0, 'anchor_value': 44.4},
            {'anchor_type': 'week_of_year', 'anchor_point': 23.0, 'anchor_value': 46.37},
            {'anchor_type': 'week_of_year', 'anchor_point': 24.0, 'anchor_value': 48.33},
            {'anchor_type': 'week_of_year', 'anchor_point': 25.0, 'anchor_value': 50.25},
            {'anchor_type': 'week_of_year', 'anchor_point': 26.0, 'anchor_value': 52.13},
            {'anchor_type': 'week_of_year', 'anchor_point': 27.0, 'anchor_value': 54.06},
            {'anchor_type': 'week_of_year', 'anchor_point': 28.0, 'anchor_value': 55.97},
            {'anchor_type': 'week_of_year', 'anchor_point': 29.0, 'anchor_value': 57.87},
            {'anchor_type': 'week_of_year', 'anchor_point': 30.0, 'anchor_value': 59.76},
            {'anchor_type': 'week_of_year', 'anchor_point': 31.0, 'anchor_value': 61.62},
            {'anchor_type': 'week_of_year', 'anchor_point': 32.0, 'anchor_value': 63.45},
            {'anchor_type': 'week_of_year', 'anchor_point': 33.0, 'anchor_value': 65.25},
            {'anchor_type': 'week_of_year', 'anchor_point': 34.0, 'anchor_value': 67.01},
            {'anchor_type': 'week_of_year', 'anchor_point': 35.0, 'anchor_value': 68.81},
            {'anchor_type': 'week_of_year', 'anchor_point': 36.0, 'anchor_value': 70.6},
            {'anchor_type': 'week_of_year', 'anchor_point': 37.0, 'anchor_value': 72.34},
            {'anchor_type': 'week_of_year', 'anchor_point': 38.0, 'anchor_value': 74.13},
            {'anchor_type': 'week_of_year', 'anchor_point': 39.0, 'anchor_value': 75.95},
            {'anchor_type': 'week_of_year', 'anchor_point': 40.0, 'anchor_value': 77.8},
            {'anchor_type': 'week_of_year', 'anchor_point': 41.0, 'anchor_value': 79.66},
            {'anchor_type': 'week_of_year', 'anchor_point': 42.0, 'anchor_value': 81.49},
            {'anchor_type': 'week_of_year', 'anchor_point': 43.0, 'anchor_value': 83.3},
            {'anchor_type': 'week_of_year', 'anchor_point': 44.0, 'anchor_value': 85.09},
            {'anchor_type': 'week_of_year', 'anchor_point': 45.0, 'anchor_value': 86.94},
            {'anchor_type': 'week_of_year', 'anchor_point': 46.0, 'anchor_value': 88.86},
            {'anchor_type': 'week_of_year', 'anchor_point': 47.0, 'anchor_value': 90.81},
            {'anchor_type': 'week_of_year', 'anchor_point': 48.0, 'anchor_value': 92.67},
            {'anchor_type': 'week_of_year', 'anchor_point': 49.0, 'anchor_value': 94.52},
            {'anchor_type': 'week_of_year', 'anchor_point': 50.0, 'anchor_value': 96.4},
            {'anchor_type': 'week_of_year', 'anchor_point': 51.0, 'anchor_value': 98.23},
            {'anchor_type': 'week_of_year', 'anchor_point': 52.0, 'anchor_value': 100.0}]
    }
}
CONFIGS = {
    "standard": {
        "sku_distribution": {
            "SKU001": 1.0,
            "SKU002": 1.0,
            "SKU003": 1.0,
            "SKU004": 1.0,
            "SKU005": 1.0,
            "SKU006": 1.0,
            "SKU007": 1.0,
            "SKU008": 1.0,
            "SKU009": 1.0,
            "SKU010": 1.0
        },
        "weekday_distribution": {
            "0": 16.0,
            "1": 16.0,
            "2": 16.0,
            "3": 16.0,
            "4": 16.0,
            "5": 10.0,
            "6": 10.0
        },
        "week_distribution": {
            "0": 1.0,
            "1": 1.0,
            "2": 1.0,
            "3": 1.0,
            "4": 1.0,
            "5": 1.0
        },
        "packages_per_sale": 1.05,
        "quantity_per_package": 6.0,
        "curve_definition": [
            {
                "anchor_type": "week_of_year",
                "anchor_point": 1,
                "anchor_value": 0.0044437223
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 2,
                "anchor_value": 0.0097458227
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 3,
                "anchor_value": 0.0152044807
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 4,
                "anchor_value": 0.0227720217
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 5,
                "anchor_value": 0.0299999573
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 6,
                "anchor_value": 0.0488551145
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 7,
                "anchor_value": 0.0807636056
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 8,
                "anchor_value": 0.0978062852
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 9,
                "anchor_value": 0.1177352605
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 10,
                "anchor_value": 0.1479006306
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 11,
                "anchor_value": 0.1778807574
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 12,
                "anchor_value": 0.2041782501
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 13,
                "anchor_value": 0.2290984277
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 14,
                "anchor_value": 0.2662544325
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 15,
                "anchor_value": 0.30245347
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 16,
                "anchor_value": 0.3238755723
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 17,
                "anchor_value": 0.3396792478
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 18,
                "anchor_value": 0.3559996364
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 19,
                "anchor_value": 0.3877249513
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 20,
                "anchor_value": 0.4134740858
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 21,
                "anchor_value": 0.4248301281
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 22,
                "anchor_value": 0.4321713753
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 23,
                "anchor_value": 0.4438707945
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 24,
                "anchor_value": 0.4578869673
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 25,
                "anchor_value": 0.4672282993
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 26,
                "anchor_value": 0.4752755682
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 27,
                "anchor_value": 0.4798395259
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 28,
                "anchor_value": 0.4857422934
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 29,
                "anchor_value": 0.4899600703
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 30,
                "anchor_value": 0.4951036533
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 31,
                "anchor_value": 0.4998731435
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 32,
                "anchor_value": 0.5069827365
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 33,
                "anchor_value": 0.5177806992
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 34,
                "anchor_value": 0.5228706931
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 35,
                "anchor_value": 0.5311203004
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 36,
                "anchor_value": 0.5405695272
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 37,
                "anchor_value": 0.5642588127
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 38,
                "anchor_value": 0.5844236853
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 39,
                "anchor_value": 0.6015985889
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 40,
                "anchor_value": 0.6240512111
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 41,
                "anchor_value": 0.6580702688
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 42,
                "anchor_value": 0.6906435688
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 43,
                "anchor_value": 0.7191996619
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 44,
                "anchor_value": 0.7558410878
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 45,
                "anchor_value": 0.8103986338
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 46,
                "anchor_value": 0.8615659803
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 47,
                "anchor_value": 0.88105529
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 48,
                "anchor_value": 0.9010466404
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 49,
                "anchor_value": 0.9322328143
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 50,
                "anchor_value": 0.9760928981
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 51,
                "anchor_value": 0.995384709
            },
            {
                "anchor_type": "week_of_year",
                "anchor_point": 52,
                "anchor_value": 1.0
            }
        ]
    },
    "traditional": {
        "shipments_per_order": 1.078,
        "products_per_shipment": 5.843
    }
}
